@@ -34,6 +34,7 @@
 #include "webenginepage.h"
 #include "websslinfo.h"
 #include "webhistoryinterface.h"
+#include "webenginewallet.h"
 
 #include "ui/searchbar.h"
 #include "ui/passwordbar.h"
@@ -80,7 +81,8 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
              m_statusBarWalletLabel(0),
              m_searchBar(0),
              m_passwordBar(0),
-             m_featurePermissionBar(0)
+             m_featurePermissionBar(0),
+             m_wallet(Q_NULLPTR)
 {
     KAboutData about = KAboutData(QStringLiteral("webenginepart"),
                                   i18nc("Program Name", "WebEnginePart"),
@@ -168,6 +170,7 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
 
     // Load plugins once we are fully ready
     loadPlugins();
+    setWallet(page()->wallet());
 }
 
 WebEnginePart::~WebEnginePart()
@@ -305,27 +308,31 @@ void WebEnginePart::connectWebEnginePageSignals(WebEnginePage* page)
 //    connect(m_browserExtension, SIGNAL(saveUrl(QUrl)),
 //            page, SLOT(downloadUrl(QUrl)));
 
-//    connect(page->mainFrame(), SIGNAL(loadFinished(bool)),
-//            this, SLOT(slotMainFrameLoadFinished(bool)));
-
-
     connect(page, &QWebEnginePage::iconUrlChanged, [page, this](const QUrl& url) {
         if (WebEngineSettings::self()->favIconsEnabled()
             && !page->profile()->isOffTheRecord()){
                 m_browserExtension->setIconUrl(url);
         }
     });
+}
 
-#if 0
-    KWebWallet *wallet = page->wallet();
-    if (wallet) {
-        connect(wallet, SIGNAL(saveFormDataRequested(QString,QUrl)),
-                this, SLOT(slotSaveFormDataRequested(QString,QUrl)));
-        connect(wallet, SIGNAL(fillFormRequestCompleted(bool)),
-                this, SLOT(slotFillFormRequestCompleted(bool)));
-        connect(wallet, SIGNAL(walletClosed()), this, SLOT(slotWalletClosed()));
+void WebEnginePart::setWallet(WebEngineWallet* wallet)
+{
+    if(m_wallet){
+        disconnect(m_wallet, &WebEngineWallet::saveFormDataRequested,
+                this, &WebEnginePart::slotSaveFormDataRequested);
+        disconnect(m_wallet, &WebEngineWallet::fillFormRequestCompleted,
+                this, &WebEnginePart::slotFillFormRequestCompleted);
+        disconnect(m_wallet, &WebEngineWallet::walletClosed, this, &WebEnginePart::slotWalletClosed);
+    }
+    m_wallet = wallet;
+    if (m_wallet) {
+        connect(m_wallet, &WebEngineWallet::saveFormDataRequested,
+                this, &WebEnginePart::slotSaveFormDataRequested);
+        connect(m_wallet, &WebEngineWallet::fillFormRequestCompleted,
+                this, &WebEnginePart::slotFillFormRequestCompleted);
+        connect(m_wallet, &WebEngineWallet::walletClosed, this, &WebEnginePart::slotWalletClosed);
     }
-#endif
 }
 
 bool WebEnginePart::openUrl(const QUrl &_u)
@@ -415,19 +422,31 @@ void WebEnginePart::slotLoadStarted()
         emit started(0);
     }
     updateActions();
+
+    // If "NoEmitOpenUrlNotification" property is set to true, do not
+    // emit the open url notification. Property is set by this part's
+    // extension to prevent openUrl notification being sent when
+    // handling history navigation requests (back/forward).
+    const bool doNotEmitOpenUrl = property("NoEmitOpenUrlNotification").toBool();
+    if (doNotEmitOpenUrl) {
+        setProperty("NoEmitOpenUrlNotification", QVariant());
+    } else {
+        if (m_emitOpenUrlNotify) {
+            emit m_browserExtension->openUrlNotify();
+        }
+    }
+    // Unless we go via openUrl again, the next time we are here we emit (e.g. after clicking on a link)
+    m_emitOpenUrlNotify = true;
 }
 
-void WebEnginePart::slotMainFrameLoadFinished (bool ok)
+void WebEnginePart::slotLoadFinished (bool ok)
 {
     if (!ok || !m_doLoadFinishedActions)
         return;
 
+    slotWalletClosed();
     m_doLoadFinishedActions = false;
 
-    if (!m_emitOpenUrlNotify) {
-        m_emitOpenUrlNotify = true; // Save history once page loading is done.
-    }
-
     // If the document contains no <title> tag, then set it to the current url.
     if (m_webView->title().trimmed().isEmpty()) {
         // If the document title is empty, then set it to the current url
@@ -443,25 +462,19 @@ void WebEnginePart::slotMainFrameLoadFinished (bool ok)
     }
     if (!Utils::isBlankUrl(url())) {
         m_hasCachedFormData = false;
-
         if (WebEngineSettings::self()->isNonPasswordStorableSite(url().host())) {
             addWalletStatusBarIcon();
-        } else {
+        } 
+        else {
 // Attempt to fill the web form...
-//          KWebWallet *webWallet = page() ? page()->wallet() : 0;
-//          if (webWallet) {
-//              webWallet->fillFormData(frame, false);
-//          }
+            WebEngineWallet *wallet = page() ? page()->wallet() : 0;
+            if (wallet){
+                wallet->fillFormData(page());
+            }
         }
     }
-}
 
-void WebEnginePart::slotLoadFinished(bool ok)
-{
     bool pending = false;
-
-    if (m_doLoadFinishedActions) {
-        updateActions();
        // QWebFrame* frame = (page() ? page()->currentFrame() : 0);
        // if (ok &&
        //     frame == page()->mainFrame() &&
@@ -472,9 +485,9 @@ void WebEnginePart::slotLoadFinished(bool ok)
        //         frame->page()->triggerAction(QWebEnginePage::Stop);
        //     }
        // }
-    }
-
     emit completed ((ok && pending));
+
+    updateActions();
 }
 
 void WebEnginePart::slotLoadAborted(const QUrl & url)
@@ -494,7 +507,7 @@ void WebEnginePart::slotUrlChanged(const QUrl& url)
         return;
 
     // Ignore if error url
-    if (url.scheme().compare(QL1S("error"), Qt::CaseInsensitive) == 0)
+    if (url.scheme() == QL1S("error"))
         return;
 
     const QUrl u (url);
@@ -548,22 +561,6 @@ void WebEnginePart::slotSaveFrameState(QWebFrame *frame, QWebHistoryItem *item)
 
     // Handle actions that apply only to the mainframe...
     if (frame == view()->page()->mainFrame()) {
-        slotWalletClosed();
-
-        // If "NoEmitOpenUrlNotification" property is set to true, do not
-        // emit the open url notification. Property is set by this part's
-        // extension to prevent openUrl notification being sent when
-        // handling history navigation requests.
-        const bool doNotEmitOpenUrl = property("NoEmitOpenUrlNotification").toBool();
-        if (doNotEmitOpenUrl) {
-            setProperty("NoEmitOpenUrlNotification", QVariant());
-        }
-
-        // Only emit open url notify for the main frame. Do not
-        if (m_emitOpenUrlNotify && !doNotEmitOpenUrl) {
-            // kDebug() << "***** EMITTING openUrlNotify" << item->url();
-            emit m_browserExtension->openUrlNotify();
-        }
     }
 
     // For some reason, QtWebEngine PORTING_TODO does not restore scroll position when
@@ -780,10 +777,10 @@ void WebEnginePart::slotDeleteNonPasswordStorableSite()
 
 void WebEnginePart::slotRemoveCachedPasswords()
 {
-    if (!page()) // || !page()->wallet())
+    if (!page() || !page()->wallet())
         return;
 
-//    page()->wallet()->removeFormData(page()->mainFrame(), true);
+    page()->wallet()->removeFormData(page());
     m_hasCachedFormData = false;
 }
 
@@ -836,8 +833,8 @@ void WebEnginePart::slotShowFeaturePermissionBar(QWebEnginePage::Feature feature
                 this, SLOT(slotFeaturePermissionGranted(QWebEnginePage::Feature)));
         connect(m_featurePermissionBar, SIGNAL(permissionDenied(QWebEnginePage::Feature)),
                 this, SLOT(slotFeaturePermissionDenied(QWebEnginePage::Feature)));
-//         connect(m_passwordBar, SIGNAL(done()),
-//                 this, SLOT(slotSaveFormDataDone()));
+        connect(m_passwordBar, SIGNAL(done()),
+                this, SLOT(slotSaveFormDataDone()));
         QBoxLayout* lay = qobject_cast<QBoxLayout*>(widget()->layout());
         if (lay)
             lay->insertWidget(0, m_featurePermissionBar);
@@ -876,19 +873,16 @@ void WebEnginePart::slotSaveFormDataRequested (const QString& key, const QUrl& u
 
     if (!m_passwordBar) {
         m_passwordBar = new PasswordBar(widget());
-#if 0
-        KWebWallet* wallet = page()->wallet();
-        if (!wallet) {
-            kWarning() << "No wallet instance found! This should never happen!";
+        if (!m_wallet) {
+            qDebug() << "No m_wallet instance found! This should never happen!";
             return;
         }
         connect(m_passwordBar, SIGNAL(saveFormDataAccepted(QString)),
-                wallet, SLOT(acceptSaveFormDataRequest(QString)));
+                m_wallet, SLOT(acceptSaveFormDataRequest(QString)));
         connect(m_passwordBar, SIGNAL(saveFormDataRejected(QString)),
-                wallet, SLOT(rejectSaveFormDataRequest(QString)));
+                m_wallet, SLOT(rejectSaveFormDataRequest(QString)));
         connect(m_passwordBar, SIGNAL(done()),
                 this, SLOT(slotSaveFormDataDone()));
-#endif
     }
 
     Q_ASSERT(m_passwordBar);
